@@ -44,6 +44,7 @@ test_fast_resolution_by_id (void)
   GrlOperationOptions *options = NULL;
   GrlMedia *media = NULL;
   GError *error = NULL;
+  GrlSource *source;
 
   test_setup_tmdb ();
 
@@ -63,7 +64,7 @@ test_fast_resolution_by_id (void)
   g_assert (media != NULL);
   grl_data_set_string (GRL_DATA (media), tmdb_id, "10528");
 
-  GrlSource *source = test_get_source();
+  source = test_get_source();
   g_assert (source);
   grl_source_resolve_sync (source,
                            media,
@@ -97,6 +98,8 @@ test_fast_resolution_by_id (void)
 int
 main(int argc, char **argv)
 {
+  gint result;
+
   g_setenv ("GRL_PLUGIN_PATH", GRILO_PLUGINS_TESTS_TMDB_PLUGIN_PATH, TRUE);
   g_setenv ("GRL_PLUGIN_LIST", TMDB_PLUGIN_ID, TRUE);
 
@@ -110,7 +113,7 @@ main(int argc, char **argv)
 
   g_test_add_func ("/tmdb/fast-resolution-by-id", test_fast_resolution_by_id);
 
-  gint result = g_test_run ();
+  result = g_test_run ();
 
   grl_deinit ();
 
